Authing class

Constructors

Authing()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

config ↔ Config
getter/setter pair
redirectUrl ↔ String
getter/setter pair
sAppId ↔ String
getter/setter pair
sHost ↔ String
getter/setter pair
sPublicKey ↔ String
getter/setter pair
sUserPoolId ↔ String
getter/setter pair

Static Methods

init(String userPoolId, String appId) → Future<void>
requestPublicConfig() → Future<void>
setOnPremiseInfo(String host, String publicKey) → void

Constants

VERSION → const String