AuthRequest class

Constructors

AuthRequest()

Properties

authingLang ↔ String
getter/setter pair
clientId ↔ String
getter/setter pair
clientSecret ↔ String?
getter/setter pair
codeChallenge ↔ String
getter/setter pair
codeVerifier ↔ String
getter/setter pair
finishLoginUrl ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nonce ↔ String
getter/setter pair
redirectUrl ↔ String
getter/setter pair
responseType ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope ↔ String
getter/setter pair
state ↔ String
getter/setter pair
token ↔ String
getter/setter pair
uuid ↔ String
getter/setter pair

Methods

createAuthRequest() → void
getScopesAsConsentBody() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited