OIDCClient class

Constructors

OIDCClient()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

authByCode(String code, AuthRequest authRequest) → Future<AuthResult>
Auth by code #
authByToken(String token, AuthRequest authRequest) → Future<AuthResult>
Auth by Authing token
buildAuthorizeUrl(AuthRequest authRequest) → Future<String>
Build authorize URL
getNewAccessTokenByRefreshToken(String refreshToken) → Future<AuthResult>
Refresh Access Token
getUserInfoByAccessToken(String accessToken, [Map? data]) → Future<Result>
Token Change user information
loginByAccount(String account, String password) → Future<AuthResult>
OIDC Login by account and password
loginByPhoneCode(String phone, String code, {String? phoneCountryCode}) → Future<AuthResult>
OIDC Login by phone code #
oauthRequest(String method, String uri, String body) → Future<Result>
prepareLogin() → Future<AuthRequest>
OIDC prepare
registerByEmail(String email, String password) → Future<AuthResult>
OIDC register a new user by email address and a password.
registerByPhoneCode(String phone, String code, String password, {String? phoneCountryCode}) → Future<AuthResult>
OIDC register a new user by phone number and an SMS verification code.
registerByUserName(String username, String password, {AuthRequest? authRequest}) → Future<AuthResult>
OIDC register a new user by username and a password.